pub trait Expected {
// Required method
fn fmt(&self, formatter: &mut Formatter<'_>) -> Result<(), Error>;
}Expand description
Expected represents an explanation of what data a Visitor was expecting
to receive.
This is used as an argument to the invalid_type, invalid_value, and
invalid_length methods of the Error trait to build error messages. The
message should be a noun or noun phrase that completes the sentence โThis
Visitor expects to receive โฆโ, for example the message could be โan
integer between 0 and 64โ. The message should not be capitalized and should
not end with a period.
Within the context of a Visitor implementation, the Visitor itself
(&self) is an implementation of this trait.
โ
fn visit_bool<E>(self, v: bool) -> Result<Self::Value, E>
where
E: de::Error,
{
Err(de::Error::invalid_type(Unexpected::Bool(v), &self))
}Outside of a Visitor, &"..." can be used.
โ
return Err(de::Error::invalid_type(
Unexpected::Bool(v),
&"a negative integer",
));Required Methods